#
# spec file for package python-casacore
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# libboost_python3-devel (libbost_python-py3-*) is for the primary python3 flavor only
%define pythons python3
%global modname casacore
Name:           python-casacore
Version:        3.5.2
Release:        2.6
Summary:        A wrapper around CASACORE, the radio astronomy library
License:        LGPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/casacore/python-casacore
Source:         https://github.com/casacore/python-casacore/archive/refs/tags/v%{version}.tar.gz#/python-casacore-%{version}-gh.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module wheel}
BuildRequires:  casacore-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libboost_python3-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  pkgconfig(wcslib)
Requires:       python-numpy
Requires:       python-six
ExcludeArch:    %ix86
%python_subpackages

%description
A python wrapper around CASACORE, the radio astronomy library

%prep
%setup -q -n python-casacore-%{version}
# empty file masking the module directory
rm pyrap/images.py

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# old python-rpm-macros for SLE/Leap: don't import casacore from current source dir
mv casacore casacore.tmp
# TestImage needs to use data files that are no longer available upstream
# TestTable tries to write to tmp dir and fails during build due to perm issues
%pytest_arch -k 'not (TestImage or TestTable)'
mv casacore.tmp casacore

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/%{modname}/
%{python_sitearch}/pyrap/
%{python_sitearch}/python_%{modname}-%{version}.dist-info/

%changelog
* Mon Sep  4 2023 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded {Build,}Requires on future and configparse.
- Switch to pyproject macros.
* Fri Jan 13 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.5.2:
  * Wheel related changes, no source related changes.
* Tue Dec  6 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.5.1:
  * No changelog.
- Changes from version 3.5.0:
  * License change to LGPL-3.0-or-later.
  * No other changelog.
- Drop Source1: WSRT_Measures_20210502-160001.ztar, no longer
  available from upstream.
- Drop tests depending on additional data or writing data to tmp
  dir.
- Drop outdated redefinitions of python rpm macros.
* Thu Jul 15 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Sync ExcludeArch with casacore: casacore is not built for %%ix86.
* Sun May  2 2021 Ben Greiner <code@bnavigator.de>
- Update to 3.4.0
  * fix compatibility with casascore 3.4.0
  * Ship binary wheels with casacore 3.4.0
- Enable test suite (GitHub archive) with Measures data
  WSRT_Measures_20210502-160001.ztar
* Thu Aug  6 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
